/*
 * StudioClientProjectConstants.java
 *
 * Copyright (C) 2022 by Posit Software, PBC
 *
 * Unless you have received this program directly from Posit Software pursuant
 * to the terms of a commercial license agreement with Posit Software, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */
package org.rstudio.studio.client.projects;

public interface StudioClientProjectConstants extends com.google.gwt.i18n.client.Messages {
    String openProjectLabel();
    String openProjectCaption();
    String projectFilter();
    String showVCSMenuLabel(String vcsName);
    String zoomVCSMenuLabel(String vcsName);
    String updateButtonLabel();
    String updateMenuLabel();
    String newProjectCaption();
    String errorCaption();
    String newProjectProjectIndicator();
    String creatingProjectError();
    String savingDefaultsLabel();
    String cloneSVNRepoLabel();
    String cloneGitRepoLabel();
    String vcsCloneFailMessage();
    String invalidPackageMessage(String packageName);
    String invalidPackageName(String packageName);
    String creatingProjectLabel();
    String projectFailedMessage();
    String creatingProjectCaption();
    String creatingProjectWithLabel(String pkg);
    String projectContext(String pkg);
    String errorInstallingCaption(String pkg);
    String errorInstallingCaptionMessage(String pkg);
    String creatingProjectResultMessage();
    String initializingGitRepoMessage();
    String initializingRenvMessage();
    String executeOpenProjectMessage();
    String noActiveProjectCaption();
    String noActiveProjectMessage();
    String versionControlProjectSetupMessage();
    String errorReadingOptionsCaption();
    String readingOptionsMessage();
    String confirmOpenProjectCaption();
    String openProjectPathMessage(String projectPath);
    String openProjectError(String project, String message);
    String openProjectErrorMessage();
    String errorOpeningProjectCaption();
    String switchProjectsCaption();
    String onShowDiagnosticsProject();
    String projectOpenError(String projectFilePath);
    String noneLabel();
    String createPackageFormLabel();
    String addButtonCaption();
    String removeButtonCaption();
    String addSourceFileCaption();
    String existingDirectoryTitle();
    String existingDirectorySubTitle();
    String existingDirectoryPageCaption();
    String projectWorkingDirectoryTitle();
    String validateMessage();
    String homeDirectoryErrorMessage();
    String cloneGitRepo();
    String cloneGitRepoPageCaption();
    String newDirectoryTitle();
    String newDirectorySubTitle();
    String newDirectoryPageCaption();
    String titleName();
    String newProjectTitle();
    String newProjectSubTitle();
    String createNewProjectPageCaption();
    String newProjectParentLabel();
    String createGitRepoLabel();
    String chkRenvInitLabel();
    String chkRenvInitUserAction();
    String directoryNameLabel();
    String specifyProjectDirectoryName();
    String newProjectWizardCaption();
    String createProjectCaption();
    String openNewSessionLabel();
    String createProjectFromLabel();
    String newPackageTitle();
    String createNewPackageSubTitle();
    String createRPackagePageCaption();
    String typeLabel();
    String packageNameLabel();
    String rcppPackageOption();
    String validateAsyncMessage(String packageName);
    String fileAlreadyExistsMessage(String path);
    String directoryAlreadyExistsMessage(String path);
    String pleaseEnterDirectoryNameMessage();
    String quartoBookTitle();
    String quartoBookSubTitle();
    String quartoBookPageCaption();
    String quartoManuscriptTitle();
    String quartoManuscriptSubTitle();
    String quartoManuscriptPageCaption();
    String quartoProjectTitle();
    String quartoProjectSubTitle();
    String quartoProjectPageCaption();
    String typeText();
    String projectTypeDefault();
    String projectTypeWebsite();
    String projectTypeBook();
    String projectTypeManuscript();
    String engineLabel();
    String engineSelectNone();
    String kernelLabel();
    String chkUseVenvLabel();
    String txtVenvPackagesNone();
    String loadingCapabilitiesLabel();
    String quartoProjectTypeOption();
    String quartoProjectEngineOption();
    String quartoProjectKernelOption();
    String quartoBlogTitle();
    String quartoBlogSubTitle();
    String quartoBlogPageCaption();
    String quartoWebsiteTitle();
    String quartoWebsiteSubTitle();
    String quartoWebsitePageCaption();
    String shinyApplicationTitle();
    String shinyApplicationSubTitle();
    String shinyApplicationPageCaption();
    String svnPageTitle();
    String svnPageSubTitle();
    String svnPagePageCaption();
    String versionControlTitle();
    String versionControlSubTitle();
    String versionControlPageCaption();
    String acceptNavigationHTML(String title, String location);
    String optionsLabel();
    String preferencesLabel();
    String vcsHelpLink(String title);
    String installationNotDetectedHTML(String title);
    String titleNotFound(String title);
    String okLabel();
    String repoURLLabel();
    String usernameLabel();
    String projDirNameLabel();
    String existingRepoDestDirLabel();
    String specifyRepoURLErrorMessage();
    String pdfGenerationCaption();
    String pdfPreviewCaption();
    String compilePDFLabel();
    String compilePDFEmptyLabel();
    String browseActionLabel();
    String rootDocumentChooserTitle();
    String chooseFileCaption();
    String enableCodeIndexingLabel();
    String chkSpacesForTabLabel();
    String tabWidthLabel();
    String useNativePipeOperatorLabel();
    String chkAutoAppendNewlineLabel();
    String chkStripTrailingWhitespaceLabel();
    String textEncodingLabel();
    String changeLabel();
    String codingEditingLabel();
    String projectGeneralInfoLabel();
    String restoreWorkspaceText();
    String saveWorkspaceText();
    String alwaysSaveHistoryText();
    String disableExecuteRprofileText();
    String quitChildProcessesOnExitText();
    String generalText();
    String initializePackratMessage();
    String chkUsePackratLabel();
    String chkAutoSnapshotLabel();
    String chkVcsIgnoreLibLabel(String vcsName);
    String chkVcsIgnoreSrcLabel(String vcsName);
    String panelExternalPackagesText();
    String panelExternalPackagesTitle();
    String packratHelpLink();
    String verifyPrerequisitesLabel();
    String packratManagePackages();
    String projectOptionsCaption();
    String restartRStudioCaption();
    String restartRStudioMessage();
    String useDefaultText();
    String environmentsText();
    String rstudioInitializeLabel();
    String renvHelpLink();
    String visualModeCaption();
    String rMarkdownInfoLabel();
    String wrapColumnLabel();
    String wrapPanelText();
    String referencesDefaultItem();
    String referencesFormLabel();
    String canonicalDefaultItem();
    String canonicalTrueItem();
    String canonicalFalseItem();
    String canonicalFormLabel();
    String markdownPerFileOptionsCaption();
    String visualModeZoteroCaption();
    String rMarkdownText();
    String appearanceText();
    String editorThemeFormLabel();
    String appearanceIgnoredByGlobalText();
    String sharingText();
    String vcsSelectLabel();
    String originLabel();
    String lblOrigin();
    String repoCaption();
    String confirmGitRepoLabel();
    String confirmGitRepoCaption();
    String confirmGitRepoMessage();
    String noneProjectSourceControlLabel();
    String dictionariesCaption();
    String dictionariesInfoLabel();
    String spellingText();
    String yesLabel();
    String noLabel();
    String askLabel();
    String pathSelectorLabel();
    String validateScriptCaption();
    String validateScriptMessage();
    String pathSelectorMakefileDirLabel();
    String txtMakefileArgs();
    String pathSelectorPackageDir();
    String chkUseDevtoolsCaption();
    String cleanBeforeInstallLabel();
    String chkUseRoxygenCaption();
    String btnConfigureRoxygenLabel();
    String installMdashArgument();
    String checkPackageMdashArgument();
    String buildSourceMdashArgument();
    String buildBinaryMdashArgument();
    String browseLabel();
    String projectRootLabel();
    String chooseDirectoryCaption();
    String noneFileSelectorLabel();
    String roxygenOptionsCaption();
    String pathSelectorSiteDir();
    String websiteOutputFormatLabel();
    String allLabel();
    String chkPreviewAfterBuildingCaption();
    String chkLivePreviewSiteCaption();
    String infoLabel();
    String chkPreviewAfterBuilding();
    String allFormatsLabel();
    String buildToolsLabel();
    String projectBuildToolsLabel();
    String packageLabel();
    String gitLabel();
    String closeProjectLabel();
    String placeholderLabel();
    String chkUseCacheLabel();
    String useCondaenv();
    String editingTitle();
    String indexingTitle();
    String savingTitle();
    String workspaceTitle();
    String miscellaneousTitle();
    String generalTitle();
    String customProjectNameLabel();
    String chkUseGitignoreLabel();
    String scratchPathLabel();
}
